/*
   This file is part of TALER
   Copyright (C) 2022 Taler Systems SA

   TALER is free software; you can redistribute it and/or modify it under the
   terms of the GNU General Public License as published by the Free Software
   Foundation; either version 3, or (at your option) any later version.

   TALER is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
   A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along with
   TALER; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */
/**
 * @file auditordb/pg_select_purse_expired.h
 * @brief implementation of the select_purse_expired function for Postgres
 * @author Christian Grothoff
 */
#ifndef PG_SELECT_PURSE_EXPIRED_H
#define PG_SELECT_PURSE_EXPIRED_H

#include "taler/taler_util.h"
#include "taler/taler_json_lib.h"
#include "taler/taler_auditordb_plugin.h"


/**
 * Get information about expired purses.
 *
 * @param cls the @e cls of this struct with the plugin-specific state
 * @param cb function to call on expired purses
 * @param cb_cls closure for @a cb
 * @return transaction status code
 */
enum GNUNET_DB_QueryStatus
TAH_PG_select_purse_expired (
  void *cls,
  TALER_AUDITORDB_ExpiredPurseCallback cb,
  void *cb_cls);

#endif
